import unittest

from krake.api import API
from krake.error import APIError


class ApiTestCase(unittest.TestCase):

    def setUp(self):
        self.api = API()

    def test_time(self):
        time = self.api.time()
        self.assertEqual(time.method, 'Time')

    def test_assets(self):
        assets = self.api.assets()
        self.assertEqual(assets.method, 'Assets')

    def test_asset_pairs(self):
        asset_pairs = self.api.asset_pairs()
        self.assertEqual(asset_pairs.method, 'AssetPairs')

    def test_ticker(self):
        ticker = self.api.ticker(pair='XXBTZEUR')
        self.assertEqual(ticker.method, 'Ticker')
        self.assertTrue('XXBTZEUR' in ticker)
        self.assertTrue('XXBTZEUR' in ticker['result'])

        ticker = self.api.ticker(pair=','.join(['XXBTZEUR', 'XXBTZGBP']))
        self.assertTrue('XXBTZEUR' in ticker and 'XXBTZGBP' in ticker)
        self.assertTrue('XXBTZEUR' in ticker['result'] and 'XXBTZGBP' in ticker['result'])

    def test_ohlc(self):
        ohlc = self.api.ohlc(pair='XXBTZEUR')
        self.assertEqual(ohlc.method, 'OHLC')

    def test_depth(self):
        depth = self.api.depth(pair='XXBTZEUR')
        self.assertEqual(depth.method, 'Depth')

    def test_trades(self):
        trades = self.api.trades(pair='XXBTZEUR')
        self.assertEqual(trades.method, 'Trades')

    def test_spread(self):
        spread = self.api.spread(pair='XXBTZEUR')
        self.assertEqual(spread.method, 'Spread')

    def test_invalid_argument(self):
        with self.assertRaises(APIError):
            self.api.ticker(pair='INVALID')
